# Generated by roxygen2: do not edit by hand

S3method(plot,kaf_fit)
S3method(predict,kaf_fit)
S3method(print,kaf_fit)
export(extract_fourier_params)
export(extract_kaf_scales)
export(kaf)
export(kaf_fit)
export(kaf_fit_formula)
export(nn_kaf)
export(nn_kaf_layer)
export(nn_random_fourier_features)
export(plot_kaf_scales)
