#' rkaf: Kolmogorov-Arnold Fourier Networks in R
#'
#' `rkaf` provides an R implementation of Kolmogorov-Arnold Fourier Networks
#' using the `torch` backend.
#'
#' The package supports:
#'
#' - regression
#' - binary classification
#' - multiclass classification
#' - formula and matrix interfaces
#' - mini-batch training
#' - validation splits
#' - early stopping
#' - automatic standardization
#' - best-model restoration
#' - KAF-specific diagnostics
#'
#' @keywords internal
"_PACKAGE"
