% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{plot.kaf_fit}
\alias{plot.kaf_fit}
\title{Plot a fitted KAF model}
\usage{
\method{plot}{kaf_fit}(x, type = c("loss", "fit"), newdata = NULL, y = NULL, ...)
}
\arguments{
\item{x}{A fitted object returned by \code{kaf_fit()}.}

\item{type}{Character. Either \code{"loss"} or \code{"fit"}.}

\item{newdata}{Optional predictors used when \code{type = "fit"}.}

\item{y}{Optional observed target values used when \code{type = "fit"}.}

\item{...}{Additional arguments passed to base plotting functions.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Plot a fitted KAF model
}
